local RS = RingSlinger

RS.AddWeapon({
	name = "Normal",
	hudsprite = "RINGIND",
	viewsprite = "TRNGD0V0",
	viewoffset = 5*FRACUNIT,
	delay = 10,
	cost = 3
})
RS.AddWeapon({
	name = "Automatic",
	viewsprite = "RNGAD0",
	hudsprite = "AUTOIND",
	mt = MT_RS_THROWNAUTOMATIC,
	sound = sfx_rs_aut,
	scale = FRACUNIT * 5/6,
	viewoffset = -15*FRACUNIT,
	auto = true,
	delay = 3,
	cost = 1,
	shake = 1
})
RS.AddWeapon({
	name = "Bounce",
	viewsprite = "RNGBD0",
	hudsprite = "BNCEIND",
	mt = MT_RS_THROWNBOUNCE,
	sound = sfx_rs_bou,
	scale = FRACUNIT * 3/2,
	viewoffset = 10*FRACUNIT,
	fuse = TICRATE * 2,
	delay = 18,
	cost = 4
})
RS.AddWeapon({
	name = "Scatter",
	viewsprite = "RNGSD0",
	hudsprite = "SCATIND",
	mt = MT_RS_THROWNSCATTER,
	fuse = 15,
	delay = 20,
	cost = 6,
	shake = 3,
	slingfunc = function(mo, weapon)
		local player = mo.player
		local mt = weapon.mt
		local spread = 15
		S_StartSound(mo, sfx_rs_sca)
		for i = -1, 1
			local shot = P_SPMAngle(mo, mt, mo.angle + i * ANG1*spread, 1, MF2_SCATTER)
			if shot and shot.valid
				shot.color = player.skincolor
				shot.lifetime = weapon.fuse
				shot.destscale = shot.scale * 4/3
				if mo.ringslinger.powers[RSPOWER_POWERTOSS]
					shot.momx = $ * 3/2
					shot.momy = $ * 3/2
					shot.momz = $ * 3/2
				end
				if mo.ringslinger.powers[RSPOWER_PIERCE]
					shot.pierce = true
				end
				shot.momx = $ + mo.momx / 3
				shot.momy = $ + mo.momy / 3
				shot.momz = $ + mo.momz / 3
			end
		end
		for i = -1, 1, 2
			local prevaim = player.aiming
			player.aiming = $ + i * ANG1*spread
			local shot = P_SPMAngle(mo, mt, mo.angle + i, 1, MF2_SCATTER)
			player.aiming = prevaim
			if shot and shot.valid
				shot.color = player.skincolor
				shot.lifetime = weapon.fuse
				shot.destscale = shot.scale * 4/3
				if mo.ringslinger.powers[RSPOWER_POWERTOSS]
					shot.momx = $ * 3/2
					shot.momy = $ * 3/2
					shot.momz = $ * 3/2
				end
				if mo.ringslinger.powers[RSPOWER_PIERCE]
					shot.pierce = true
				end
				shot.momx = $ + mo.momx / 3
				shot.momy = $ + mo.momy / 3
				shot.momz = $ + mo.momz / 3
			end
		end
	end
})
RS.AddWeapon({
	name = "Grenade",
	viewsprite = "RNGGD0",
	hudsprite = "GRENIND",
	mt = MT_RS_THROWNGRENADE,
	sound = sfx_rs_gre,
	scale = FRACUNIT * 7/4,
	viewoffset = 25*FRACUNIT,
	fuse = 72,
	delay = 18,
	cost = 5
})
RS.AddWeapon({
	name = "Explosion",
	viewsprite = "RNGED0",
	hudsprite = "BOMBIND",
	mt = MT_RS_THROWNEXPLOSION,
	flags2 = MF2_EXPLOSION,
	sound = sfx_rs_exp,
	delay = 32,
	shake = 2,
	cost = 6
})

local ring = function(x,y,z,scale,angle)
	local th = P_SpawnMobj(x, y, z, MT_THOK)
	if th and th.valid
		th.angle = angle + ANGLE_90
		th.spriteyoffset = -20*FRACUNIT
		th.sprite = SPR_STAB
		th.frame = FF_PAPERSPRITE|TR_TRANS80
		th.color = SKINCOLOR_WHITE
		th.blendmode = AST_ADD
		th.colorized = true
		th.scale = scale
		th.destscale = th.scale*6
		th.scalespeed = $ * 2
		th.tics = 6
	end
end
RS.AddWeapon({
	name = "Rail",
	viewsprite = "RNGRD0",
	hudsprite = "RAILIND",
	delay = 32,
	cost = 7,
	shake = 7,
	slingfunc = function(mo, weapon)
		local player = mo.player
		S_StartSound(mo, sfx_rs_rai)
		S_StartSoundAtVolume(mo, sfx_cdfm16, 60)
		local rail = P_SPMAngle(mo, MT_RS_RAILSHOT, mo.angle, 1, MF2_SCATTER|MF2_DONTDRAW)
		
		if rail and rail.valid
			local range = 28
			if mo.ringslinger.powers[RSPOWER_POWERTOSS]
				range = $ * 3/2
			end
			if mo.ringslinger.powers[RSPOWER_PIERCE]
				rail.pierce = true
			end
			for i = 0, range
				if i % 2 == 0
					local spark = P_SpawnMobj(rail.x, rail.y, rail.z, MT_SPARK)
					if spark and spark.valid
						if i % 3 == 0
							spark.color = player.skincolor
							spark.colorized = true
						else
							spark.scale = $ * 3/4
							if mo.ringslinger.powers[RSPOWER_PIERCE]
								spark.color = SKINCOLOR_RED
								spark.colorized = true
							end
						end
					end
					if (i - 2) % 10 == 0
						ring(rail.x,rail.y,rail.z,rail.scale/2,rail.angle)
					end
				end
				
				local prevx = rail.x
				local prevy = rail.y
				local prevz = rail.z
				
				if rail.momx or rail.momy
					P_XYMovement(rail)
					if not rail.valid
						break
					end
				end
				if rail.momz
					P_ZMovement(rail)
					if not rail.valid
						break
					end
				end
				
				if (not rail.valid) or (xx == rail.x and y == rail.y and z == rail.z)
					break
				end
			end
			if rail and rail.valid
				ring(rail.x,rail.y,rail.z,rail.scale,rail.angle)
				S_StartSound(rail, sfx_rail2)
				P_KillMobj(rail)
			end
		end
	end
})
RS.AddWeapon({
	name = "Seeker",
	viewsprite = "RNGMW0",
	hudsprite = "HOMNIND",
	mt = MT_RS_THROWNSEEKER,
	sound = sfx_rs_hom,
	fuse = TICRATE * 2,
	scale = FRACUNIT * 6/5,
	viewoffset = 10*FRACUNIT,
	delay = 25,
	cost = 6
})
RS.AddWeapon({
	name = "Accel",
	viewsprite = "RNGCB0",
	hudsprite = "CROSIND",
	mt = MT_RS_THROWNACCEL,
	sound = sfx_rs_cro,
	scale = FRACUNIT * 6/5,
	delay = 12,
	cost = 4
})
/*RS.AddWeapon({
	name = "Wave",
	viewsprite = "RNGWA0",
	hudsprite = "WAVEIND",
	mt = MT_RS_THROWNWAVE,
	sound = sfx_rs_wav,
	delay = 20,
	cost = 8
})*/
/*RS.AddWeapon({
	name = "Infinity",
	viewsprite = "RNGID0",
	hudsprite = "INFNIND",
	mt = MT_RS_THROWNINFINITY,
	sound = sfx_rs_inf,
	viewoffset = -2*FRACUNIT,
	delay = 8,
	cost = 0
})*/
RS.AddWeapon({
	name = "Splash",
	viewsprite = "RNGPA0",
	hudsprite = "SPLAIND",
	mt = MT_RS_THROWNSPLASH,
	sound = sfx_rs_spl,
	fuse = TICRATE,
	viewoffset = 6*FRACUNIT,
	delay = 20,
	cost = 7
})
/*RS.AddWeapon({
	name = "Flame",
	viewsprite = "FLMEA0",
	hudsprite = "AUTOIND",
	mt = MT_RS_THROWNAUTOMATIC,
	sound = sfx_fire,
	mutetoss = true,
	hold = true,
	scale = FRACUNIT * 1,
	viewoffset = 15*FRACUNIT,
	auto = true,
	delay = 1,
	shake = 1,
	cost = 1
})*/
/*RS.AddWeapon({
	name = "Mini",
	hudsprite = "MINIIND",
	viewsprite = "TRNGD0V0",
	mt = MT_RS_MINISHOT,
	viewoffset = -20*FRACUNIT,
	scale = FRACUNIT/2,
	delay = 7,
	cost = 2
})
RS.AddWeapon({
	name = "Mega",
	hudsprite = "GIGAIND",
	viewsprite = "TRNGD0V0",
	mt = MT_RS_MEGASHOT,
	viewoffset = 65*FRACUNIT,
	scale = FRACUNIT*2,
	delay = 13,
	cost = 2
})*/
RS.AutoGenerateMax = #RS.Weapons--Do not autogenerate any weapons added by other scripts, only autogenerate RSNEO default weapons.